@@ -5,7 +5,7 @@ use warnings;
 use Net::Curl ();
 use Exporter 'import';
 
-our $VERSION = 0.27;
+our $VERSION = 0.28;
 
 our @EXPORT_OK = grep { /^CURL/x } keys %{Net::Curl::Easy::};
 our %EXPORT_TAGS = ( constants => \@EXPORT_OK );
@@ -133,7 +133,7 @@ Throws L</Net::Curl::Easy::Code> on error.
 
 =item reset( )
 
-Reinitializes easy handle.
+Reinitializes easy handle B<(was broken before v0.27!)>.
 
  $easy->reset();
 
